@@ -637,7 +637,7 @@ applix_parse_style (ApplixReadState *state, unsigned char **buffer)
 
 #if 0
 				/* FIXME : Add these to gnumeric ? */
-				case 'GR0' : Graph ?  Seems like a truncated integer histogram
+				case "GR0" : Graph ?  Seems like a truncated integer histogram
 					     /* looks like crap, no need to support */
 
 #endif
@@ -1214,11 +1214,9 @@ applix_read_cells (ApplixReadState *state)
 					parse_error_free (&perr);
 					texpr = gnm_expr_top_new_constant (value_new_string (expr_string));
 				} else if (is_array) {
-					gnm_expr_top_ref (texpr);
-					gnm_cell_set_array_formula (sheet,
-								r.start.col, r.start.row,
-								r.end.col, r.end.row,
-								texpr);
+					gnm_cell_set_array (sheet,
+							    &r,
+							    texpr);
 					gnm_cell_assign_value (cell, val);
 					/* Leak? */
 				} else {
