@@ -1288,14 +1288,18 @@ sheet_object_view_button_pressed (GocItem *item, int button, double x, double y)
 {
 	GnmPane *pane;
 	SheetObject *so;
+	g_printf("\nWcisniety button %d ", button);
 	if (IS_GNM_PANE (item->canvas)) {
 		if (scg_wbcg (GNM_SIMPLE_CANVAS (item->canvas)->scg)->new_object) {
 			ItemGrid *grid = GNM_PANE (item->canvas)->grid;
+			g_printf("\n1 if");
 			return GOC_ITEM_GET_CLASS (grid)->button_pressed (GOC_ITEM (grid), button, x, y);
 		}
 
-		if (button > 3)
+		if (button > 3){
+			g_printf("\n2 if");
 			return FALSE;
+		}
 
 		pane = GNM_PANE (item->canvas);
 		so = (SheetObject *) g_object_get_qdata (G_OBJECT (item), sov_so_quark);
@@ -1304,26 +1308,39 @@ sheet_object_view_button_pressed (GocItem *item, int button, double x, double y)
 		y *= goc_canvas_get_pixels_per_unit (item->canvas);
 		/* cb_sheet_object_widget_canvas_event calls even if selected */
 		if (NULL == g_hash_table_lookup (pane->drag.ctrl_pts, so)) {
+			g_printf("\n3 if");
 			SheetObjectClass *soc =
 				G_TYPE_INSTANCE_GET_CLASS (so, SHEET_OBJECT_TYPE, SheetObjectClass);
 			GdkEventButton *event = (GdkEventButton *) goc_canvas_get_cur_event (item->canvas);
 
-			if (soc->interactive && button != 3)
+			if (soc->interactive && button != 3){
+				g_printf("\n3.1 if");
 				return FALSE;
+			}
 
-			if (!(event->state & GDK_SHIFT_MASK))
+			if (!(event->state & GDK_SHIFT_MASK)){
+				g_printf("\n3.2 if");
+				gnm_pane_display_object_menu (pane, so, goc_canvas_get_cur_event (item->canvas));
+				return TRUE;
+			}
+			else{
+				g_printf("\n3.2 else");
 				scg_object_unselect (pane->simple.scg, NULL);
+			}
 			scg_object_select (pane->simple.scg, so);
-			if (NULL == g_hash_table_lookup (pane->drag.ctrl_pts, so))
+			if (NULL == g_hash_table_lookup (pane->drag.ctrl_pts, so)){
+				g_printf("\n3.3 if");
 				return FALSE;	/* protected ? */
+			}
 		}
 
-		if (button < 3)
+		if (button < 3){
 			gnm_pane_object_start_resize (pane, button, x, y, so, 8, FALSE);
-		else
-			gnm_pane_display_object_menu (pane, so, goc_canvas_get_cur_event (item->canvas));
+		}
 	} else {
-		//if (button == 3) {
+		g_printf("\nelse");
+		if (button == 1) {
+			g_printf("\nelse 1 if");
 			GPtrArray *actions = g_ptr_array_new ();
 			GtkWidget *menu;
 			unsigned i = 0;
@@ -1333,6 +1350,7 @@ sheet_object_view_button_pressed (GocItem *item, int button, double x, double y)
 
 			if (actions->len == 0) {
 				g_ptr_array_free (actions, TRUE);
+				g_printf("\nelse 2 if");
 				return FALSE;
 			}
 
@@ -1343,7 +1361,7 @@ sheet_object_view_button_pressed (GocItem *item, int button, double x, double y)
 				(GDestroyNotify) cb_ptr_array_free);
 			gtk_widget_show_all (menu);
 			gnumeric_popup_menu (GTK_MENU (menu), &goc_canvas_get_cur_event (item->canvas)->button);
-		//}
+		}
 	}
 	return TRUE;
 }
